@@ -200,10 +200,9 @@ class SVG:
             svg.shapes_to_paths(inplace=True)
             return svg
 
-        tolerance = self.tolerance
         swaps = []
         for idx, (el, (shape,)) in enumerate(self._elements()):
-            self.elements[idx] = (el, (shape.as_path(tolerance),))
+            self.elements[idx] = (el, (shape.as_path(),))
         return self
 
     def _xpath(self, xpath, el=None):
@@ -236,7 +235,7 @@ class SVG:
 
             new_el = copy.deepcopy(target)
 
-            group = etree.Element("g")
+            group = etree.Element(f"{{{svgns()}}}g", nsmap=self.svg_root.nsmap)
             use_x = use_el.attrib.get("x", 0)
             use_y = use_el.attrib.get("y", 0)
             if use_x != 0 or use_y != 0:
@@ -278,15 +277,13 @@ class SVG:
 
         # union all the shapes under the clipPath
         # Fails if there are any non-shapes under clipPath
-        clip_path = svg_pathops.union(
-            self.tolerance, *[from_element(e) for e in clip_path_el]
-        )
+        clip_path = svg_pathops.union(*[from_element(e) for e in clip_path_el])
         return clip_path
 
     def _combine_clip_paths(self, clip_paths):
         # multiple clip paths leave behind their intersection
         if len(clip_paths) > 1:
-            return svg_pathops.intersection(self.tolerance, *clip_paths)
+            return svg_pathops.intersection(*clip_paths)
         elif clip_paths:
             return clip_paths[0]
         return None
@@ -423,10 +420,7 @@ class SVG:
             return field.name.startswith("stroke")
 
         # map old fields to new dest
-        _stroke_fields = {
-            "stroke": "fill",
-            "stroke_opacity": "opacity",
-        }
+        _stroke_fields = {"stroke": "fill", "stroke_opacity": "opacity"}
 
         if shape.stroke == "none":
             return (shape,)
@@ -497,9 +491,9 @@ class SVG:
         # apply clip path to target
         for el_idx, clip_path in clips:
             el, (target,) = self.elements[el_idx]
-            target = target.as_path(self.tolerance).absolute(inplace=True)
+            target = target.as_path().absolute(inplace=True)
 
-            target.d = svg_pathops.intersection(self.tolerance, target, clip_path).d
+            target.d = svg_pathops.intersection(target, clip_path).d
             target.clip_path = ""
             self._set_element(el_idx, el, (target,))
 
@@ -535,7 +529,7 @@ class SVG:
                     )
                 el = el.getparent()
             if transform != Affine2D.identity():
-                new_shapes.append((idx, shape.transform(transform, self.tolerance)))
+                new_shapes.append((idx, shape.transform(transform)))
 
         for el_idx, new_shape in new_shapes:
             el, _ = self.elements[el_idx]
@@ -659,6 +653,7 @@ class SVG:
         self.remove_comments(inplace=True)
         self.shapes_to_paths(inplace=True)
         self.resolve_use(inplace=True)
+        self.apply_transforms(inplace=True)
         self.apply_clip_paths(inplace=True)
         self.ungroup(inplace=True)
         # stroke after ungroup to apply group strokes properly
